.. _recipes:

Recipes (``pyzome.recipes``)
=====================================
Functions that combine pyzome operations and diagnostics to 
perform more complex tasks or analyses. 

Functions
---------
.. autofunction:: pyzome.recipes.create_zonal_mean_dataset
